@@ -1,4 +1,7 @@
-from collections import Iterable
+try:
+    from collections import Iterable
+except ImportError:
+    from collections.abc import Iterable
 import json
 import os
 
@@ -286,13 +289,10 @@ class BaseEndpoint(object):
                     else:
                         self.fieldsets = fieldsets[self.model.__name__]
             except FileNotFoundError:
-                print('FILE NOT FOUND', fieldsets_path)
                 pass
             except KeyError:
-                print('KEY NOT FOUND', self.model.__name__)
                 pass
 
-
         if self.fieldsets is not None:
             return [{'key': field} if not isinstance(field, dict)
                     else field
@@ -520,5 +520,5 @@ class Endpoint(BaseEndpoint, metaclass=EndpointMetaClass):
         if self.model is None:
             try:
                 self.model = self.get_serializer().Meta.model
-            except:
+            except Exception:
                 pass
